import japanese
pass_chars = ['。', '、', ' ', '\n', '\t', '\b', '\r', '\f']


def upper(string: str) -> str:
    """Convert to Ōmoji every char.
    Args:
        string(str): Check string
    Returns:
        Converted string(str)
    """
    if(isinstance(string, str)):  # string is str
        for char in string:
            if(char in japanese.komoji_to_omoji_dict):
                # replace komoji to omoji
                string = string.replace(
                    char, japanese.komoji_to_omoji_dict[char])
        return string
    else:
        raise ValueError('arg must be str')


def lower(string: str) -> str:
    """Convert to Komoji every char.
    Args:
        string(str): Check string
    Returns:
        Converted string(str)
    """
    if(isinstance(string, str)):  # string is str
        for char in string:
            if(char in japanese.omoji_to_komoji_dict):
                # replace omoji to komoji
                string = string.replace(
                    char, japanese.omoji_to_komoji_dict[char])
        return string
    else:
        raise ValueError('arg must be str')



from setuptools import setup

setup(
    name='japanese',
    version='0.1',
    descrption='Python Japanese library for Humans',
    url='https://github.com/kekeho/japanese',
    author='Hiroki Takemura',
    author_email='hirodora@me.com',
    license='MIT',
    keywords='japanese utils util',
    packages=["japanese",],
    classifiers=[
        'Programming Language :: Python :: 3.6',
        'Natural Language :: Japanese'
    ]
)


import japanese
pass_chars = ['。', '、', ' ', '\n', '\t', '\b', '\r', '\f']


def hiragana(string: str) -> bool:
    """Is this hiragana?
    Check all char in string is Hiragana.

    Args:
        string(str): check string.
    Returns:
        bool: 
            True: String is completely written by Hiragana.
            False: Hiragana is included in string.
    """
    for char in string:
        if(char in pass_chars or char in japanese.hira_to_katakana_dict):
            pass
        else:
            return False
    # every char is Hiragana
    return True


def katakana(string: str) -> bool:
    """Is this katakana?
    Check all char in string is Katakana.

    Args:
        string(str): check string.
    Returns:
        bool:
            True: String is completely written by Katakana.
            False: Katakana is included in string.
    """
    for char in string:
        if(char in pass_chars or char in japanese.katakana_to_hira_dict):
            pass
        else:
            return False
    # every char is Katakana
    return True


def omoji(string: str) -> bool:
    """Is this Ōmoji?
    Check all char in string is Ōmoji.

    Args:
        string(str): check string.
    Returns:
        bool:
            True: String is completely written by Ōmoji.
            False: Komoji (and more) is included in string.
    """
    for char in string:
        if(char in pass_chars or char not in japanese.komoji_dict):
            pass
        else:
            return False
    # every char is Ōmoji
    return True


def komoji(string: str) -> bool:
    """Is this Komoji?
    Check all char in string is Komoji.

    Args:
        string(str): check string.
    Returns:
        bool:
            True: String is completely written by Komoji.
            False: Komoji
    """
    for char in string:
        if(char in pass_chars or char in japanese.komoji_dict):
            pass
        else:
            return False
    # every char is komoji
    return True
